@@ -30,7 +30,7 @@
 #include <KMessageBox>
 #include <KSelectAction>
 #include <KStandardAction>
-#include <KStandardGameAction>
+#include <KGameStandardAction>
 // Qt
 #include <QFileDialog>
 #include <QGroupBox>
@@ -66,7 +66,7 @@ KWin4App::KWin4App(QWidget *parent)
     // Read theme files
     QStringList themeList;
     const QString dir = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("grafix"), QStandardPaths::LocateDirectory);
-    const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
+    const QStringList fileNames = QDir(dir).entryList({QStringLiteral("*.desktop")});
     for (const QString &file : fileNames)
         themeList.append(dir + QLatin1Char('/') + file);
 
@@ -79,7 +79,7 @@ KWin4App::KWin4App(QWidget *parent)
     // Read theme files
     for (int i = 0; i < themeList.size(); i++) {
         KConfig themeInfo(themeList.at(i), KConfig::SimpleConfig);
-        KConfigGroup themeGroup(&themeInfo, "Theme");
+        KConfigGroup themeGroup(&themeInfo, QStringLiteral("Theme"));
         QString name = themeGroup.readEntry("Name", QString());
         QString file = themeGroup.readEntry("File", QString());
         bool isDefault = themeGroup.readEntry("Default", false);
@@ -207,47 +207,49 @@ void KWin4App::checkMenus(CheckFlags menu)
 
     // Check file menu
     if (!menu || (menu & CheckFileMenu)) {
-        changeAction("move_hint", !(!isRunning && localgame));
-        changeAction("game_new", !isRunning);
-        changeAction("game_save", isRunning);
-        changeAction("game_end", isRunning);
+        changeAction(KGameStandardAction::name(KGameStandardAction::Hint), !(!isRunning && localgame));
+        changeAction(KGameStandardAction::name(KGameStandardAction::New), !isRunning);
+        changeAction(KGameStandardAction::name(KGameStandardAction::Save), isRunning);
+        changeAction(KGameStandardAction::name(KGameStandardAction::End), isRunning);
     }
 
     // Edit menu
     if (!menu || (menu & CheckEditMenu)) {
+        const QString moveUndoActionId = KGameStandardAction::name(KGameStandardAction::Undo);
         if (!isRunning || !localgame) {
-            disableAction("move_undo");
+            disableAction(moveUndoActionId);
         } else if (mDoc->getHistoryCnt() == 0) {
-            disableAction("move_undo");
+            disableAction(moveUndoActionId);
         } else if (mDoc->getCurrentMove() < 1) {
-            disableAction("move_undo");
+            disableAction(moveUndoActionId);
         } else {
-            enableAction("move_undo");
+            enableAction(moveUndoActionId);
         }
 
         // Show redo
+        const QString moveRedoActionId = KGameStandardAction::name(KGameStandardAction::Redo);
         if (!isRunning || !localgame) {
-            disableAction("move_redo");
+            disableAction(moveRedoActionId);
         } else if (mDoc->getHistoryCnt() == mDoc->getMaxMove()) {
-            disableAction("move_redo");
+            disableAction(moveRedoActionId);
         } else {
-            enableAction("move_redo");
+            enableAction(moveRedoActionId);
         }
     }
 
     // Disable some menus in demo mode
     if (global_demo_mode) {
         disableAction(KStandardAction::name(KStandardAction::Preferences));
-        disableAction("move_undo");
-        disableAction("move_redo");
-        disableAction("game_new");
-        disableAction("game_end");
-        disableAction("game_save");
-        disableAction("game_open");
-        disableAction("network_conf");
-        disableAction("network_chat");
-        disableAction("statistics");
-        disableAction("move_hint");
+        disableAction(KGameStandardAction::name(KGameStandardAction::Undo));
+        disableAction(KGameStandardAction::name(KGameStandardAction::Redo));
+        disableAction(KGameStandardAction::name(KGameStandardAction::New));
+        disableAction(KGameStandardAction::name(KGameStandardAction::End));
+        disableAction(KGameStandardAction::name(KGameStandardAction::Save));
+        disableAction(KGameStandardAction::name(KGameStandardAction::Load));
+        disableAction(QStringLiteral("network_conf"));
+        disableAction(QStringLiteral("network_chat"));
+        disableAction(QStringLiteral("statistics"));
+        disableAction(KGameStandardAction::name(KGameStandardAction::Hint));
     }
 }
 
@@ -257,13 +259,13 @@ void KWin4App::initGUI()
     QAction *action;
 
     // Game
-    KStandardGameAction::gameNew(this, &KWin4App::menuNewGame, actionCollection());
-    KStandardGameAction::load(this, &KWin4App::menuOpenGame, actionCollection());
-    KStandardGameAction::save(this, &KWin4App::menuSaveGame, actionCollection());
-    action = KStandardGameAction::end(this, &KWin4App::endGame, actionCollection());
+    KGameStandardAction::gameNew(this, &KWin4App::menuNewGame, actionCollection());
+    KGameStandardAction::load(this, &KWin4App::menuOpenGame, actionCollection());
+    KGameStandardAction::save(this, &KWin4App::menuSaveGame, actionCollection());
+    action = KGameStandardAction::end(this, &KWin4App::endGame, actionCollection());
     action->setWhatsThis(i18n("Ends a currently played game. No winner will be declared."));
-    KStandardGameAction::hint(this, &KWin4App::askForHint, actionCollection());
-    KStandardGameAction::quit(this, &KWin4App::close, actionCollection());
+    KGameStandardAction::hint(this, &KWin4App::askForHint, actionCollection());
+    KGameStandardAction::quit(this, &KWin4App::close, actionCollection());
 
     action = actionCollection()->addAction(QStringLiteral("network_conf"));
     action->setText(i18n("&Network Configuration..."));
@@ -280,8 +282,8 @@ void KWin4App::initGUI()
     action->setToolTip(i18n("Show statistics."));
 
     // Move
-    KStandardGameAction::undo(this, &KWin4App::undoMove, actionCollection());
-    KStandardGameAction::redo(this, &KWin4App::redoMove, actionCollection());
+    KGameStandardAction::undo(this, &KWin4App::undoMove, actionCollection());
+    KGameStandardAction::redo(this, &KWin4App::redoMove, actionCollection());
 
     KStandardAction::preferences(this, &KWin4App::configureSettings, actionCollection());
 
@@ -338,13 +340,9 @@ void KWin4App::connectDocument()
 }
 
 // Enable or disable an action
-void KWin4App::changeAction(const char *action, bool enable)
+void KWin4App::changeAction(const QString &action, bool enable)
 {
-    if (!action) {
-        return;
-    }
-
-    QAction *act = actionCollection()->action(QLatin1String(action));
+    QAction *act = actionCollection()->action(action);
     if (act) {
         act->setEnabled(enable);
     }
@@ -392,7 +390,7 @@ void KWin4App::saveProperties()
     KConfig *config = KSharedConfig::openConfig().data();
 
     // Program data
-    KConfigGroup cfg = config->group("ProgramData");
+    KConfigGroup cfg = config->group(QStringLiteral("ProgramData"));
     cfg.writeEntry("ThemeIndexNo", mThemeIndexNo);
 
     mDoc->writeConfig(config);
@@ -407,7 +405,7 @@ void KWin4App::readProperties()
     KConfig *config = KSharedConfig::openConfig().data();
 
     // Program data
-    KConfigGroup cfg = config->group("ProgramData");
+    KConfigGroup cfg = config->group(QStringLiteral("ProgramData"));
     mThemeIndexNo = cfg.readEntry("ThemeIndexNo", themeIdxFromName(mThemeDefault));
     if (mThemeIndexNo >= mThemeFiles.size())
         mThemeIndexNo = 0;
